################################################################################
# Time-stamp: <Wed 2017-08-23 15:14 svarrette>
#
# File::      <tt>common.pp</tt>
# Author::    UL HPC Team (hpc-sysadmins@uni.lu)
# Copyright:: Copyright (c) 2018 UL HPC Team
# License::   Apache-2.0
#
# ------------------------------------------------------------------------------
# = Class: redis::common
#
# Base class to be inherited by the other redis classes, containing the common code.
#
# Note: respect the Naming standard provided here[http://projects.puppetlabs.com/projects/puppet/wiki/Module_Standards]
#
class redis::common {

  # Load the variables used in this module. Check the params.pp file
  require ::redis::params

  package { 'redis':
    ensure => $redis::ensure,
    name   => $redis::params::packagename,
  }

  file { 'redis.conf':
    ensure  => $redis::ensure,
    path    => $redis::params::configfile,
    owner   => $redis::params::configfile_owner,
    group   => $redis::params::configfile_group,
    mode    => $redis::params::configfile_mode,
    content => template('redis/redis.conf.erb'),
    require => [
      Package['redis']
    ],
  }

  service { 'redis':
    ensure    => ($redis::ensure == 'present'),
    name      => $redis::params::servicename,
    enable    => ($redis::ensure == 'present'),
    require   => [
      Package['redis'],
      File[$redis::params::configfile],
    ],
    subscribe => File['redis.conf'],
  }

}
