################################################################################
# Time-stamp: <Fri 2018-01-26 17:38:40 hcartiaux>
#
# File::      <tt>init.pp</tt>
# Author::    UL HPC Team (hpc-sysadmins@uni.lu)
# Copyright:: Copyright (c) 2018 UL HPC Team
# License::   Apache-2.0
#
# ------------------------------------------------------------------------------
# == Class: redis
#
# Configure and manage redis and sentinel
#
#
# @param ensure [String] Default: 'present'.
#          Ensure the presence (or absence) of redis
#
# === Requires
#
# n/a
#
# @example Basic instanciation
#
#     include '::redis'
#
# You can then specialize the various aspects of the configuration,
# for instance:
#
#         class { '::redis':
#             ensure => 'present'
#         }
#
# === Authors
#
# The UL HPC Team <hpc-sysadmins@uni.lu> of the University of Luxembourg, in
# particular
# * Sebastien Varrette <Sebastien.Varrette@uni.lu>
# * Valentin Plugaru   <Valentin.Plugaru@uni.lu>
# * Sarah Peter        <Sarah.Peter@uni.lu>
# * Hyacinthe Cartiaux <Hyacinthe.Cartiaux@uni.lu>
# * Clement Parisot    <Clement.Parisot@uni.lu>
# See AUTHORS for more details
#
# === Warnings
#
# /!\ Always respect the style guide available here[http://docs.puppetlabs.com/guides/style_guide]
#
# [Remember: No empty lines between comments and class definition]
#
class redis(
    String  $ensure            = $redis::params::ensure,
    String  $bind              = $redis::params::bind,
    Integer $port              = $redis::params::port,
    String  $requirepass       = $redis::params::requirepass,
    String  $masterauth        = $redis::params::masterauth,
    String  $redis_master_ip   = $redis::params::redis_master_ip,
    Integer $redis_master_port = $redis::params::redis_master_port
)
inherits redis::params
{
    validate_legacy('String', 'validate_re', $ensure, ['^present', '^absent'])

    info ("Configuring redis (with ensure = ${ensure})")

    case $::operatingsystem {
        /(?i-mx:centos|fedora|redhat)/: { include ::redis::common::redhat }
        default: {
            fail("Module ${module_name} is not supported on ${::operatingsystem}")
        }
    }
}
