################################################################################
# Time-stamp: <Wed 2017-08-23 15:15 svarrette>
#
# File::      <tt>params.pp</tt>
# Author::    UL HPC Team (hpc-sysadmins@uni.lu)
# Copyright:: Copyright (c) 2018 UL HPC Team
# License::   Apache-2.0
#
# ------------------------------------------------------------------------------
# == Class: redis::params
#
# In this class are defined as variables values that are used in other
# redis classes and definitions.
# This class should be included, where necessary, and eventually be enhanced
# with support for more Operating Systems.
#
# == Warnings
#
# /!\ Always respect the style guide available
# here[http://docs.puppetlabs.com/guides/style_guide]
#
# [Remember: No empty lines between comments and class definition]
#
class redis::params {

  # ensure the presence (or absence) of redis
  $ensure = 'present'

  ## Define a `bind` address pointing to a local IP that your other machines
  ## can reach you. If you really need to bind to an external accessible IP, make
  ## sure you add extra firewall rules to prevent unauthorized access:
  $bind = $::ipaddress

  ## Define a `port` to force redis to listen on TCP so other machines can
  ## connect to it (default port is `6379`)
  $port = 6379

  ## Set up password authentication (use the same password in all nodes).
  ## The password should be defined equal for both `requirepass` and `masterauth`
  ## when setting up Redis to use with Sentinel.
  $requirepass = 'Ch4ng3Me*'
  $masterauth  = 'Ch4ng3Me*'

  ## Define `slaveof` pointing to the Redis master instance with IP and port.
  $redis_master_ip   = ''
  $redis_master_port = 6379

  ## Define a `port` to force Sentinel to listen on TCP so other machines can
  ## connect to it (default port is `6379`).
  $sentinel_port = 26379

  $sentinel_quorum = 2

  ## Define with `sentinel down-after-milliseconds` the time in `ms`
  ## that an unresponsive server will be considered down.
  $redis_timeout = 10000
  $failover_timeout = 30000

  #### MODULE INTERNAL VARIABLES  #########
  # (Modify to adapt to unsupported OSes)
  #########################################

  # redis packages
  $packagename = $::operatingsystem ? {
    default => 'redis',
  }

  # redis associated services
  $servicename = $::operatingsystem ? {
    /(?i-mx:redhat|centos)/ => 'redis',
    default                 => 'redis'
  }
  # redis associated services
  $sentinel_servicename = $::operatingsystem ? {
    /(?i-mx:redhat|centos)/ => 'redis-sentinel',
    default                 => 'redis-sentinel'
  }


  $configfile = $::operatingsystem ? {
    default => '/etc/redis.conf',
  }
  $sentinel_configfile = $::operatingsystem ? {
    default => '/etc/redis-sentinel.conf',
  }
  $configfile_mode = $::operatingsystem ? {
    default => '0640',
  }
  $configfile_owner = $::operatingsystem ? {
    default => 'redis',
  }
  $configfile_group = $::operatingsystem ? {
    default => 'root',
  }

}
