################################################################################
# Time-stamp: <Fri 2018-01-26 17:58:01 hcartiaux>
#
# File::      <tt>common.pp</tt>
# Author::    UL HPC Team (hpc-sysadmins@uni.lu)
# Copyright:: Copyright (c) 2018 UL HPC Team
# License::   Apache-2.0
#
# ------------------------------------------------------------------------------
# = Class: redis::sentinel::common
#
# Base class to be inherited by the other redis classes, containing the common code.
#
# Note: respect the Naming standard provided here[http://projects.puppetlabs.com/projects/puppet/wiki/Module_Standards]
#
class redis::sentinel::common {

  # Load the variables used in this module. Check the params.pp file
  require ::redis::params

  file { 'sentinel.conf':
    ensure  => $redis::sentinel::ensure,
    path    => $redis::params::sentinel_configfile,
    owner   => $redis::params::configfile_owner,
    group   => $redis::params::configfile_group,
    mode    => $redis::params::configfile_mode,
    content => template('redis/sentinel.conf.erb'),
    require => [
      Package['redis']
    ],
  }

  service { 'sentinel':
    ensure    => ($redis::sentinel::ensure == 'present'),
    name      => $redis::params::sentinel_servicename,
    enable    => ($redis::sentinel::ensure == 'present'),
    require   => [
      Package['redis'],
      File[$redis::params::sentinel_configfile],
    ],
    subscribe => File['sentinel.conf'],
  }

}
